@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.55 $
+//$Revision: 1.56 $
 #include <hk_datasource.h>
 
 #include "hk_kdeboolean.h"
@@ -440,7 +440,7 @@ else
 	if (v=="=%TRUE% ") setChecked(true);
 	else
 	if (v=="=%FALSE% ") setChecked(false);
-	cerr <<"v=#"<<v<<"#"<<endl;
+// 	cerr <<"v=#"<<v<<"#"<<endl;
 	}
 	else
 	cerr <<" mode_changed no filtervalue()"<<endl;
