@@ -16,7 +16,7 @@
 /**
  *
  *@short KDE Widget to edit/display data in a combobox.
- *@version $Revision: 1.32 $
+ *@version $Revision: 1.34 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -40,6 +40,7 @@ friend class qlineedit;
 virtual void show_widget(void);
 virtual void hide_widget(void);
 virtual bool close_widget(void);
+        virtual void update_filter(void);
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
@@ -67,10 +68,12 @@ virtual bool close_widget(void);
         virtual void widget_specific_backgroundcolour_changed(const hk_colour&);
         virtual void widget_specific_foregroundcolour_changed(const hk_colour&);
         virtual void            mouseDoubleClickEvent(QMouseEvent*);
+	virtual void    before_presentationmode_changed(void);
 
     protected slots:
         void slot_data_changed(int);
         void slot_text_changed(void);
+        void slot_focus_lost(void);
 
     private:
         void load_listitems_from_column();
@@ -83,6 +86,7 @@ virtual bool close_widget(void);
         void        set_selecteditemdata(int);
         int         find_edittextitem(void);
 	hk_kdecomboboxprivate* p_private;
+        bool p_filter_has_changed;
 
 };
 #endif
