@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -31,7 +31,7 @@ class QProgressDialog;
 /**
  *
  *@short KDE Widget frontend to import CSV data
- *@version $Revision: 1.10 $
+ *@version $Revision: 1.15 $
  *@author Horst Knorr (hk_classes@knoda.org)
  */
 
@@ -42,6 +42,12 @@ class hk_kdecsvimportdialog : public hk_kdecsvimportdialogbase  ,public hk_impor
         public:
         hk_kdecsvimportdialog( QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
         ~hk_kdecsvimportdialog();
+        virtual void        set_datasource(hk_datasource* d);
+
+  public slots:
+      virtual void help_clicked();
+      virtual void morebutton_clicked();
+
 
     protected slots:
         virtual void filebutton_clicked();
@@ -51,14 +57,17 @@ class hk_kdecsvimportdialog : public hk_kdecsvimportdialogbase  ,public hk_impor
 
     protected:
         virtual bool widget_specific_after_new_row(void);
+        void set_tablepreview(void);
+virtual void keyPressEvent ( QKeyEvent * e );
+ static  bool set_progress(long int,long int,const hk_string&);
     private:
 //  hk_importcsv* p_import;
         void before_execute(void);
         void after_execute(void);
         QString      p_file;
         QString      p_tab;
-        bool p_cancelprinting;
-        QProgressDialog* p_progressdialog;
+        static bool p_cancelimport;
+static        QProgressDialog* p_progressdialog;
 
 };
 #endif                                            // HK_KDECSVIMPORTDIALOG_H
