@@ -8,11 +8,12 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
- //$Revision: 1.3 $
+ //$Revision: 1.4 $
 #ifndef HK_KDEDATABASESETTING_H
 #define HK_KDEDATABASESETTING_H
 #include "hk_kdedatabasesettingbase.h"
 class hk_database;
+class KListViewItem;
 
 class hk_kdedatabasesetting : public hk_kdedatabasesettingbase
 {
@@ -28,9 +29,12 @@ public slots:
     virtual void ok_clicked();
     virtual void alload_changed();
     virtual void allstore_changed();
+    virtual void encoding_changed();
 
 private:
 hk_database* p_database;    
+KListViewItem* p_systemtableitem;
+KListViewItem* p_localeitem;
 
 };
 
