@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.51 $
+//$Revision: 1.53 $
 #include <assert.h>
 #include "hk_kdedbdesigner.h"
 #include "hk_kdeformdatasourcedialog.h"
@@ -263,10 +263,10 @@ void hk_kdefieldlist::mouseMoveEvent(QMouseEvent* event)
 	QString n;
 	//cerr <<"drag wert="<<index(itemAt(event->pos()))<<endl;
 	n.setNum(p_datasourceframe->datasource()->presentationnumber());
-	n="<VUPN>"+n+"</VUPN>\n<VALUE>"+( itemAt(event->pos())?itemAt(event->pos())->text():QString("")) +"</VALUE>\n";
+	n="<DRAG><VUPN>"+n+"</VUPN>\n<VALUE>"+( itemAt(event->pos())?itemAt(event->pos())->text():QString("")) +"</VALUE></DRAG>\n";
 	//cerr<<"dragwert"<<n<<endl;
         QCString cstr =n.utf8();
-	//cerr<"cstr"<<cstr<<endl;
+ 	cerr<<"cstr:"<<cstr<<endl;
         p_drag->setEncodedData(cstr);
         p_drag->dragCopy();
 
@@ -289,11 +289,13 @@ void hk_kdefieldlist::dragEnterEvent(QDragEnterEvent* event)
 void hk_kdefieldlist::dropEvent(QDropEvent* event)
 {
    if (!event->encodedData("application/x-hk_kdedbdesigner")) return;
-   hk_string eventtxt=u2l(event->encodedData("application/x-hk_kdedbdesigner").data());
+   hk_string eventtxt=event->encodedData("application/x-hk_kdedbdesigner").data();
+   xmlDocPtr doc=xmlParseMemory(eventtxt.c_str(),eventtxt.size());
+   xmlNodePtr node=xmlDocGetRootElement(doc);
    long mastervupn;
    hk_string mastertxt;
-   if (!(     hk_class::get_tagvalue(eventtxt,"VUPN",mastervupn)
-         && hk_class::get_tagvalue(eventtxt,"VALUE",mastertxt)))
+   if (!(     hk_class::get_tagvalue(node,"VUPN",mastervupn)
+         && hk_class::get_tagvalue(node,"VALUE",mastertxt)))
 	 {
             hk_class::show_warningmessage("Error in drag&drop protocol");
               cerr <<eventtxt<<endl;
