@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.37 $
+//$Revision: 1.39 $
 
 #include "hk_kdeformpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -148,6 +148,7 @@ hk_kdeformpartwidget::hk_kdeformpartwidget( hk_kdeformpart* formpart,QWidget* pa
 
     p_taborderaction=new KAction(i18n("Tab order"),"bottom",0,this,SLOT(taborder_clicked()),formpart->actionCollection(),"taborder");
 
+    p_reloadaction=new KAction(i18n("Reload"),"reload",0,this,SLOT(reload_form()),formpart->actionCollection(),"reload");
 
 
     p_bulkaction->insert(p_bulkfontaction);
@@ -919,4 +920,12 @@ while (vit!=v->end())
 
 }
 
+void hk_kdeformpartwidget::reload_form(void)
+{
+  unsigned long rp=0;
+  if (p_form->datasource()) rp=p_form->datasource()->row_position();
+  p_form->enable_datasources(false);
+  p_form->enable_datasources(true);
+  if (p_form->datasource() && rp>0) p_form->datasource()->goto_row(rp);
+}
 
