@@ -38,7 +38,7 @@ class hk_kdeformpart;
  *
  *@short  KDE high level widget to display and design forms
  *@author Horst Knorr (hk_classes@knoda.org)
- *@version $Revision: 1.18 $
+ *@version $Revision: 1.19 $
  *
  *this is a high level widget to display and design forms. It hereby uses @ref hk_kdesimpleform.
  *To use it set the database with @ref set_database. If you want to show or edit an existing form
@@ -162,6 +162,7 @@ virtual bool close_widget(void);
 	void show_gridcolumndialog();
 	void filterdefinebutton_clicked();
 	void clear_filter();
+	void reload_form();
     private:
         KRadioAction* p_designaction;
         KRadioAction* p_viewaction;
@@ -193,6 +194,7 @@ virtual bool close_widget(void);
         KAction* p_copyaction;
         KAction* p_pasteaction;
         KAction* p_cutaction;
+        KAction* p_reloadaction;
         KAction*       p_formpropertyaction;
         KActionMenu* p_resizeaction;
         KAction* p_minwidthaction;
