@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.37 $
+// $Revision: 1.38 $
 
 #include "hk_kdegridcolumndialog.h"
 
@@ -214,6 +214,7 @@ void hk_kdegridcolumndialog::okbutton_clicked()
             gc->set_alignment((*it).alignment);
             gc->set_numberformat((*it).use_separators,(*it).digits);
             gc->set_displayname((*it).displayname);
+            gc->set_identifier((*it).identifier);
             gc->set_readonly((*it).readonly);
 
 	    gc->set_on_click_action((*it).p_clickaction,true,true);
@@ -299,6 +300,7 @@ void hk_kdegridcolumndialog::set_columnvalues()
         }
         f.name=gc->columnname();
         f.defaultvalue=gc->raw_defaultvalue();
+        f.identifier=gc->identifier();
         f.alignment=gc->alignment();
         f.use_separators=gc->use_numberseparator();
         f.displayname=gc->displayname();
@@ -415,6 +417,10 @@ void hk_kdegridcolumndialog::rightbox_selectionchanged(QListViewItem* i)
     displayfield->setText( QString::fromUtf8 (l2u((*p_currentfieldit).displayname).c_str()));
     displayfield->blockSignals(false);
 
+    identifierfield->blockSignals(true);
+    identifierfield->setText( QString::fromUtf8 (l2u((*p_currentfieldit).identifier).c_str()));
+    identifierfield->blockSignals(false);
+
     readonlyfield->blockSignals(true);
     readonlyfield->setCurrentItem( ((*p_currentfieldit).readonly?0:1));
     readonlyfield->blockSignals(false);
@@ -506,6 +512,14 @@ void hk_kdegridcolumndialog::displayname_changed()
 }
 
 
+void hk_kdegridcolumndialog::identifier_changed()
+{
+    if (p_currentfieldit!=fields.end())
+        (*p_currentfieldit).identifier=u2l(identifierfield->text().utf8().data());
+
+}
+
+
 void hk_kdegridcolumndialog::digits_changed()
 {
     if (p_currentfieldit!=fields.end())
