@@ -258,7 +258,7 @@ bool hk_kdeimage::widget_specific_coordinates(uint px,uint py,uint pwidth,uint p
     hkdebug("hk_kdeimage::widget_specific_coordinates");
 #endif
     setGeometry(px,py,pwidth,pheight);
-    qApp->processEvents();
+//     qApp->processEvents();
 
     return true;
 }
