@@ -34,7 +34,7 @@ class hk_kdeinterpreterdialogprivate;
 /**
  *
  *@short KDE high level widget to define queries and see the result.
- *@version $Revision: 1.9 $
+ *@version $Revision: 1.10 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *hk_kdeinterpreterdialog is a high level widget to define queries and see the result.
@@ -63,8 +63,6 @@ enum DialogCode { Rejected, Accepted };
         bool has_changed(void){return p_has_changed;}
 	void set_caption(hk_visible*,const hk_string &action);
     public slots:
-        void savebutton_clicked(void);
-        void saveasbutton_clicked(void);
 
         void print(void);
 	void undo(void);
@@ -89,13 +87,11 @@ enum DialogCode { Rejected, Accepted };
 	void slot_undo_changed(void);
 
     private:
-        void set_caption(void);
         bool p_autoclose;
         bool p_has_changed;
 
 
 //    QMultiLineEdit* p_design;
-        QWidget*    p_qbe;
         Kate::View*    p_designkate;
 	Kate::Document* p_katepart;
         bool highlighting_set;
