@@ -9,7 +9,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.71 $
+//$Revision: 1.77 $
 #include "hk_kdelineedit.h"
 #include "hk_kdelineedit.moc"
 #include <qkeycode.h>
@@ -26,6 +26,7 @@ hk_kdelineedit::hk_kdelineedit(QWidget* wid,hk_form* form)
 ,hk_dslineedit(form)
 {
     QObject::connect(this,SIGNAL(textChanged(const QString& )),this,SLOT(slot_data_changed()));
+    QObject::connect(this,SIGNAL(lostFocus()),this,SLOT(slot_focus_lost()));
 #ifdef HK_DEBUG
     hkclassname("hk_kdelineedit");
     hkdebug("hk_kdelineedit::hk_kdelineedit");
@@ -35,6 +36,7 @@ hk_kdelineedit::hk_kdelineedit(QWidget* wid,hk_form* form)
     set_alignment(hk_dslineedit::alignment(),false);
     p_finddialog=NULL;
     p_findfirstview=true;
+    p_filter_has_changed=false;
     findpopupid=0;
     //p_while_keyaction=false;
 
@@ -115,7 +117,7 @@ void hk_kdelineedit::keyPressEvent( QKeyEvent * e )
         {
             if (e->key()==Key_F && e->state()&ControlButton) find_clicked(findpopupid);
             else
-            if ((column()&&column()->is_readonly())||is_readonly())
+            if ((column()&&column()->is_readonly())||is_readonly() &&!(p_presentation && p_presentation->mode()==hk_presentation::filtermode))
             {
                 switch (e->key())
                 {
@@ -150,6 +152,14 @@ void hk_kdelineedit::slot_data_changed(void)
 #ifdef HK_DEBUG
     hkdebug("kdelineedit::slot_data_changed");
 #endif
+    
+    if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+    {
+    
+    p_filter_has_changed=true;
+    return;
+    }
+    
     if (!p_widget_specific_row_change)
     {
 #ifdef HK_DEBUG
@@ -169,13 +179,36 @@ void hk_kdelineedit::slot_data_changed(void)
 }
 
 
+void hk_kdelineedit::slot_focus_lost()
+{
+   if (!p_filter_has_changed) return;
+   p_filter_has_changed=false;
+   if (p_presentation && p_presentation->mode()==hk_presentation::filtermode && !signalsBlocked())
+    {
+    if (set_filtervalue(u2l(text().utf8().data())))
+    {
+        blockSignals(true);
+        setText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+    {
+     hk_string r="Error in statement:#"+ u2l(text().utf8().data())+"#";
+     show_warningmessage(r);
+    }
+    
+    return;
+    }
+
+}
+
 bool hk_kdelineedit::widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight)
 {
 #ifdef HK_DEBUG
     hkdebug("kdelineedit::widget_specific_coordinates");
 #endif
     setGeometry(px,py,pwidth,pheight);
-    qApp->processEvents();
+//     qApp->processEvents();
 
     return true;
 }
@@ -201,7 +234,9 @@ bool hk_kdelineedit::widget_specific_row_change(void)
             v=format_number(v,true,use_numberseparator(),commadigits(),locale());
         }
 
+        blockSignals(true);
         setText(QString::fromUtf8 (l2u(v).c_str()));
+        blockSignals(false);
         if (hk_dsdatavisible::alignment()==hk_dsdatavisible::alignleft)
             setCursorPosition(0);
     }
@@ -537,6 +572,18 @@ hk_string hk_kdelineedit::value(void)
   else return hk_dslineedit::value();
 }
 
+void    hk_kdelineedit::before_presentationmode_changed(void)
+{
+// slot_focus_lost();
+}
+
+void hk_kdelineedit::update_filter(void)
+{
+slot_focus_lost();
+
+}
+
+
 
 bool	hk_kdelineedit::presentationmode_changed(void)
 {
@@ -545,15 +592,28 @@ if (!p_presentation)
     return hk_dslineedit::presentationmode_changed();
   }
 
-bool result=hk_dslineedit::presentationmode_changed();
-if (p_presentation->mode()==hk_presentation::designmode)
+ bool result=hk_dslineedit::presentationmode_changed();
+ if (p_presentation->mode()==hk_presentation::designmode)
    {
     setEnabled(false);
         blockSignals(true);
         setText("");
         blockSignals(false);
    }
- else
+ else 
+   if (p_presentation->mode()==hk_presentation::filtermode)
+   {
+    if ( columnname().size()>0 && datasource())
+    {
+       setEnabled(true);
+        blockSignals(true);
+        setText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+      setEnabled(false);
+   }
+  else
  {
    setEnabled(is_enabled());
    if (!datasource()||!column())
