@@ -23,7 +23,7 @@ class hk_dsgridcolumn;
 /**
  *
  *@short KDE Widget to edit/display data in a field.
- *@version $Revision: 1.27 $
+ *@version $Revision: 1.29 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -40,6 +40,7 @@ class  hk_kdelineedit : public KLineEdit , public hk_dslineedit
 virtual void show_widget(void);
 virtual void hide_widget(void);
 virtual bool close_widget(void);
+        virtual void update_filter(void);
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
@@ -66,6 +67,7 @@ virtual bool close_widget(void);
         virtual void widget_specific_foregroundcolour_changed(const hk_colour&);
 	virtual void widget_specific_enabled_changed(void);
 	virtual bool	presentationmode_changed(void);
+	virtual void    before_presentationmode_changed(void);
 
     public slots:
         void    find_clicked(int);
@@ -74,6 +76,7 @@ virtual bool close_widget(void);
 
     protected slots:
         void     slot_data_changed(void);
+        void     slot_focus_lost(void);
         void    NULLselected( int r );
 
     private:
@@ -85,6 +88,7 @@ virtual bool close_widget(void);
         void    reposition(void);
         int     NULLpopupid;
         int     findpopupid;
+        bool p_filter_has_changed;
 	//bool p_while_keyaction;
 
 };
