@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.57 $
+//$Revision: 1.61 $
 #include <hk_datasource.h>
 #include <qbrush.h>
 #include <hk_kdememo.h>
@@ -33,6 +33,7 @@ hk_kdememo::hk_kdememo(QWidget* wid,hk_form* f):QTextEdit(wid,NULL), hk_dsmemo(f
     QObject::connect(this,SIGNAL(textChanged()),this,SLOT(slot_data_changed()));
     QObject::connect(this,SIGNAL(clicked(int,int)),this,SLOT(slot_mouse_clicked()));
     QObject::connect(this,SIGNAL(doubleClicked(int,int)),this,SLOT(slot_mouse_doubleclicked()));
+    QObject::connect(this,SIGNAL(lostFocus()),this,SLOT(slot_focus_lost()));
     p_widget_specific_row_change=true;
     setEnabled(false);
     setTabChangesFocus(true);
@@ -50,6 +51,7 @@ hk_kdememo::hk_kdememo(QWidget* wid,hk_form* f):QTextEdit(wid,NULL), hk_dsmemo(f
     widget_specific_font_changed();
     p_widget_specific_row_change=false;
     p_finddialog=NULL;
+    p_filter_has_changed=false;
 }
 
 
@@ -67,6 +69,14 @@ void hk_kdememo::slot_data_changed(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdememo::slot_data_changed");
 #endif
+    if (p_presentation && p_presentation->mode()==hk_presentation::filtermode)
+    {
+    
+    p_filter_has_changed=true;
+    return;
+    }
+    
+    
     if (!p_widget_specific_row_change)
     {
         has_changed=true;
@@ -356,7 +366,10 @@ void hk_kdememo::widget_specific_alignment(void)
         default       : f= Qt::AlignLeft;
 
     }
+//     bool r=p_widget_specific_row_change;
+    blockSignals(true);
     setAlignment(f);
+    blockSignals(false);
 // cout <<" hk_kdememo::widget_specific_alignment "<<f<<endl;
 
 }
@@ -530,8 +543,8 @@ void hk_kdememo::set_value(const hk_string&v)
 {
  hk_column* c=column();
  hk_dsmemo::set_value(v);
- if (!c) setText(QString::fromUtf8 (l2u(v).c_str()));
-
+ if (!c||p_presentation->mode()==hk_presentation::filtermode) 
+   setText(QString::fromUtf8 (l2u(v).c_str()));
 }
 
 hk_string hk_kdememo::value(void)
@@ -553,6 +566,19 @@ if (p_presentation->mode()==hk_presentation::designmode)
         setText("");
         blockSignals(false);
    }
+ else 
+   if (p_presentation->mode()==hk_presentation::filtermode)
+   {
+    if ( columnname().size()>0 && datasource())
+    {
+       setEnabled(true);
+        blockSignals(true);
+        setText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+      setEnabled(false);
+   }
  else
  {
    setEnabled(is_enabled());
@@ -578,6 +604,8 @@ void hk_kdememo::focusOutEvent ( QFocusEvent * e)
 {
   action_on_loosefocus();
   QTextEdit::focusOutEvent(e);
+  emit  lostFocus();
+
 
 }
 
@@ -601,3 +629,41 @@ void hk_kdememo::widget_specific_enabled_changed(void)
 {
   setEnabled(is_enabled());
 }
+
+
+
+void hk_kdememo::slot_focus_lost()
+{
+   if (!p_filter_has_changed) return;
+   p_filter_has_changed=false;
+   if (p_presentation && p_presentation->mode()==hk_presentation::filtermode && !signalsBlocked())
+    { 
+    if (set_filtervalue(u2l(text().utf8().data())))
+    {
+        blockSignals(true);
+        setText(QString::fromUtf8(l2u(filtervalue()).c_str()));
+        blockSignals(false);
+    }
+    else
+    {
+     hk_string r="Error in statement:#"+ u2l(text().utf8().data())+"#";
+     show_warningmessage(r);
+    }
+    
+    return;
+    }
+
+}
+
+void    hk_kdememo::before_presentationmode_changed(void)
+{
+// slot_focus_lost();
+}
+
+void hk_kdememo::update_filter(void)
+{
+slot_focus_lost();
+
+}
+
+
