@@ -18,7 +18,7 @@ class hk_kdefinddialog;
 /**
  *
  *@short KDE Widget to edit/display long data like text in a field.
- *@version $Revision: 1.23 $
+ *@version $Revision: 1.25 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *Just set the datasource and the column (defined in the parent class @ref hk_dsdatavisible).
@@ -36,6 +36,10 @@ class hk_kdememo: public QTextEdit,public hk_dsmemo
 virtual void show_widget(void);
 virtual void hide_widget(void);
 virtual bool close_widget(void);
+        virtual void update_filter(void);
+
+    signals:
+        void lostFocus();
 
     protected:
      virtual void focusInEvent ( QFocusEvent * );
@@ -59,6 +63,7 @@ virtual bool close_widget(void);
         virtual void widget_specific_foregroundcolour_changed(const hk_colour&);
         void   keyPressEvent ( QKeyEvent * e );
         virtual QPopupMenu* createPopupMenu(const QPoint&);
+	virtual void    before_presentationmode_changed(void);
 
     protected slots:
         void     slot_data_changed(void);
@@ -67,6 +72,7 @@ virtual bool close_widget(void);
         void    slot_mouse_clicked(void);
         void    slot_mouse_doubleclicked(void);
         void    NULLselected( int r );
+        void     slot_focus_lost(void);
     public slots:
         void    find_clicked(int);
         void    find_next(void);
@@ -81,6 +87,7 @@ virtual bool close_widget(void);
         int     findpopupid;
         hk_kdefinddialog* p_finddialog;
         bool          p_findfirstview;
+        bool p_filter_has_changed;
 
 };
 #endif
