@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
- //$Revision: 1.5 $
+ //$Revision: 1.7 $
 #include "hk_kdeobjecthandler.h"
 #include "hk_kdedblistview.h"
 #include <hk_database.h>
@@ -65,9 +65,11 @@ void hk_kdeobjecthandler::download_clicked()
   if (centrallistview->is_queryitem()) f=ft_query;
   else
   if (centrallistview->is_formitem()) f=ft_form;
+  else
+  if (centrallistview->is_moduleitem()) f=ft_module;
   
-  hk_string data=p_database->load_central(centrallistview->currentItem()->text(0).local8Bit().data(),f);
-  p_database->save_local(data,centrallistview->currentItem()->text(0).local8Bit().data(),f,true,true); 
+  hk_string data=p_database->load_central(u2l(centrallistview->currentItem()->text(0).utf8().data()),f);
+  p_database->save_local(data,u2l(centrallistview->currentItem()->text(0).utf8().data()),f,true,true); 
 }
 
 
@@ -78,9 +80,11 @@ void hk_kdeobjecthandler::upload_clicked()
   if (locallistview->is_queryitem()) f=ft_query;
   else
   if (locallistview->is_formitem()) f=ft_form;
+  else
+  if (locallistview->is_moduleitem()) f=ft_module;
   
-  hk_string data=p_database->load_local(locallistview->currentItem()->text(0).local8Bit().data(),f);
-  p_database->save_central(data,locallistview->currentItem()->text(0).local8Bit().data(),f,true,true); 
+  hk_string data=p_database->load_local(u2l(locallistview->currentItem()->text(0).utf8().data()),f);
+  p_database->save_central(data,u2l(locallistview->currentItem()->text(0).utf8().data()),f,true,true); 
 
 }
 
