@@ -41,7 +41,6 @@ hk_kdepreferencesdialog::hk_kdepreferencesdialog( QWidget* parent,  const char*
     regionaltab->changeTab(printerpage,i18n("&Printer"));
     regionaltab->changeTab(generalpage,i18n("&General"));
     driverpathlabel->setText( i18n( "Driverpath:"  ) );
-    encodinglabel->setText( i18n( "Fontencoding:"  ) );
     printcommandlabel->setText( i18n( "Printcommand:"  ) );
     bepedanticlabel->setText( i18n( "Show all questions:"  ) );
     maximizedlabel->setText( i18n( "Show maximized:"  ) );
@@ -49,20 +48,37 @@ hk_kdepreferencesdialog::hk_kdepreferencesdialog( QWidget* parent,  const char*
     fontlabel->setText(i18n("Default Font:"));
     defaultdriverlabel->setText(i18n("Default driver:"));
     QFontDatabase*p_fontdatabase = new QFontDatabase();
-    QStringList strlist=p_fontdatabase->families();
+/*    QStringList strlist=p_fontdatabase->families();*/
+        list<hk_string>* flist=hk_font::fontlist();
     QStringList newstrlist;
-    for (QStringList::iterator it=strlist.begin();it!=strlist.end();++it)
+    list<hk_string>::iterator fit=flist->begin();
+    while(fit!=flist->end())
     {
-        QString f=(*it);
-        int pos= f.find("[",0);
-        if (pos!=-1) f.truncate(pos-1);
+        QString f=QString::fromUtf8(l2u(*fit).c_str());
+        /*int pos= f.find("[",0);
+        if (pos!=-1) f.strlist.begin()truncate(pos-1);
 	// eliminate fonts with a space in the name
 	pos=f.find(" ",0);
-
-        if (!newstrlist.contains(f)&&pos==-1)
+	
+        if (!newstrlist.contains(f)&&pos==-1) */
 	   newstrlist.append(f);
+    ++fit;
     }
 
+    
+//     QStringList newstrlist;
+//     for (QStringList::iterator it=strlist.begin();it!=strlist.end();++it)
+//     {
+//         QString f=(*it);
+//         int pos= f.find("[",0);
+//         if (pos!=-1) f.truncate(pos-1);
+// 	// eliminate fonts with a space in the name
+// 	pos=f.find(" ",0);
+// 
+//         if (!newstrlist.contains(f)&&pos==-1)
+// 	   newstrlist.append(f);
+//     }
+
     fontfield->insertStringList(newstrlist);
     delete p_fontdatabase;
     QString left=i18n("Left");
@@ -103,6 +119,7 @@ hk_kdepreferencesdialog::hk_kdepreferencesdialog( QWidget* parent,  const char*
     datetimefield->setText(QString::fromUtf8(l2u(hk_class::defaultdatetimeformat()).c_str()));
     localefield->setText(QString::fromUtf8(l2u(hk_class::locale()).c_str()));
     printcommandfield->setText(QString::fromUtf8(l2u(hk_report::printcommand()).c_str()));
+    embedfontsfield->setCurrentItem(hk_report::embedfonts()?0:1);
     driverpathfield->setText(QString::fromUtf8(l2u(hk_drivermanager::path()).c_str()));
     bepedanticfield->setCurrentItem(hk_class::showpedantic()?0:1);
     maximizedfield->setCurrentItem(hk_visible::open_maximized_windows()?0:1);
@@ -131,19 +148,7 @@ hk_kdepreferencesdialog::hk_kdepreferencesdialog( QWidget* parent,  const char*
             defaultdriverfield->setCurrentItem(di);
         di++;
     }
-
-    list<hk_string>* encodelist =hk_report::fontencodinglist();
-    encodingfield->clear();
-    list<hk_string>::iterator eit=encodelist->begin();
     int i=0;
-    while (eit!=encodelist->end())
-    {
-        encodingfield->insertItem(QString::fromUtf8(l2u((*eit)).c_str()));
-        if ((*eit)==hk_report::fontencodingstring()) encodingfield->setCurrentItem(i);
-        eit++;
-        i++;
-    }
-
     switch (hk_visible::defaulttextalignment())
     {
         case hk_visible::aligncenter: i=1;break;
@@ -196,8 +201,8 @@ KConfig* c=kapp->config();
 	 hk_class::set_locale(u2l(localefield->text().utf8().data()));
         hk_class::set_showpedantic( bepedanticfield->currentItem()==0);
         hk_visible::set_open_maximized_windows(maximizedfield->currentItem()==0);
-        hk_report::set_fontencoding(u2l(encodingfield->currentText().utf8().data()));
         hk_report::set_printcommand(u2l(printcommandfield->text().utf8().data()));
+        hk_report::set_embedfonts(embedfontsfield->currentItem()==0);
         hk_drivermanager::set_path(u2l(driverpathfield->text().utf8().data()));
         hk_font::set_defaultfont(u2l(fontfield->currentText().utf8().data()),fontsizefield->value());
 	hk_presentation::set_snap2gridx(snap2gridxfield->value());
