@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU General Public License version 2 as published by the Free Software
@@ -22,9 +22,11 @@ class hk_kdepreferencesdialog : public hk_kdepreferencesdialogbase
         ~hk_kdepreferencesdialog();
     public slots:
         void driverpathbutton_clicked();
+      virtual void help_clicked();
    protected:
-    
+
+virtual void keyPressEvent ( QKeyEvent * e );
     void accept(void);
- 
+
 };
 #endif                                            // HK_KDEPREFERENCESDIALOG_H
