@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -76,16 +76,23 @@ class hk_kdeproperty : public hk_kdepropertyeditorbase,public hk_class
         void onloosefocusbutton_clicked(void);
         void onkeybutton_clicked(int rownumber,const hk_string& warningmessage);
         void onkeybutton_clicked(void);
+        void onselectbutton_clicked(int rownumber,const hk_string& warningmessage);
+        void onvaluechangedbutton_clicked(int rownumber,const hk_string& warningmessage);
+        void onvaluechangedbutton_clicked(void);
+    virtual void onselectbutton_clicked();
     virtual void use_textlist_changed();
     virtual void use_textlistbutton_clicked();
 
     virtual void border_changes();
     virtual void subformbutton_clicked();
+    virtual void localimage_selected();
+    virtual void has_changed();
+    virtual void buttonformat_changed();
 
     protected:
             bool eventFilter(QObject* object,QEvent* event);
 
-    
+
     private:
         hk_visible* p_visible;
 // change the propertyfields when hk_visible changes
@@ -97,12 +104,14 @@ class hk_kdeproperty : public hk_kdepropertyeditorbase,public hk_class
         void set_button(void);
 	void set_subform(void);
 	void set_labelvisible(void);
+	void set_imagevisible(void);
 
 //change values in hk_visible when the property fields changes
         void set_objectvisible();
         void set_objectdsvisible(void);
         void set_objectdsdatavisible(void);
 	void set_objectsubform(void);
+	void set_objectimagevisible(void);
         void set_objectaction(void);
         void set_viewcolumnvalues(void);
         void use_editor(QLineEdit* e);
