@@ -81,7 +81,11 @@ bool delete_rows(void)
 	   }
 	  
 	   myarray.sort();
-	   if (myarray.size()==0) return false;
+	   if (myarray.size()==0) 
+	   {
+	   p_qbe->slot_has_changed();
+	   return false;
+	   }
 	   removeColumns(myarray);
            setCurrentCell(currentRow(),leftcol);
          }
@@ -130,10 +134,13 @@ virtual void contentsDropEvent(QDropEvent* event)
       return;
     }
    hk_string eventtxt=u2l(event->encodedData("application/x-hk_kdedbdesigner").data());
-   long vupn;
+
+   xmlDocPtr doc=xmlParseMemory(eventtxt.c_str(),eventtxt.size());
+   xmlNodePtr node=xmlDocGetRootElement(doc);
+      long vupn;
    hk_string columnname;
-   if (!(     hk_class::get_tagvalue(eventtxt,"VUPN",vupn)
-         && hk_class::get_tagvalue(eventtxt,"VALUE",columnname)))
+   if (!(     hk_class::get_tagvalue(node,"VUPN",vupn)
+         && hk_class::get_tagvalue(node,"VALUE",columnname)))
 	 {
             hk_class::show_warningmessage("Error in drag&drop protocol");
             cerr <<eventtxt<<endl;
@@ -360,7 +367,10 @@ void hk_kdeqbe::set_has_changed(void)
     hkdebug("hk_kdeqbe::set_has_changed");
 #endif
   hk_qbe::set_has_changed();
-  if (! block_has_changed()) emit signal_qbe_has_changed();
+  if (! block_has_changed()) 
+   {
+    emit signal_qbe_has_changed();
+   }
 }
 
 
@@ -442,6 +452,22 @@ void hk_kdeqbe::value_changed(int row, int col)
       {
          set_columnnames(col);
       }
+    else
+      {
+        if (row>=R_CRITERIA)
+        {
+  	  hk_connection* c=NULL;
+          if (database())c=database()->connection();
+          hk_string result=u2l(p_private->p_table->item(row,col)->text().utf8().data());
+          if (!hk_dsdatavisible::parsed_value(result,c)) return ;
+          result=replace_all("%VALEND%",replace_all("%COLNAME%",result,""),"");
+          blockSignals(true);
+          p_private->p_table->setText(row,col,QString::fromUtf8(l2u(result).c_str()));
+          blockSignals(false);
+          if (! block_has_changed()) emit signal_qbe_has_changed();
+        
+        }
+      }
 }
 
 
@@ -473,6 +499,7 @@ void hk_kdeqbe::set_columnnames(int col)
       }
      }
     }
+    strlist.sort();
    item->setStringList(strlist);
 }
 
@@ -598,7 +625,7 @@ void hk_kdeqbe::set_columnvalues(void)
   set_block_has_changed(false);
 }
 
-void hk_kdeqbe::loaddata(const hk_string& definition)
+void hk_kdeqbe::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_kdeqbe::loaddata");
