@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.62 $
+//$Revision: 1.64 $
 
 #include "hk_kdequery.h"
 #include "hk_kdequery.moc"
@@ -53,7 +53,7 @@ hk_kdequery::hk_kdequery(QWidget* w,const char* n,WFlags f):KParts::DockMainWind
 #endif
     resize( 596, 480 );
     p_partmanager=new KParts::PartManager(this);
-    
+
     QPixmap p;
     KDockWidget* maindock=createDockWidget("",p,0,"");
     maindock->setEnableDocking(KDockWidget::DockNone);
@@ -62,23 +62,24 @@ hk_kdequery::hk_kdequery(QWidget* w,const char* n,WFlags f):KParts::DockMainWind
     loader->addAppDir("hk_kdeclasses");
     setXMLFile(locate("data","hk_kdeclasses/hk_kdequery.rc"));
 
-    
-    
+
+
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdequerypart" );
     p_part=(KParts::ReadWritePart*) p_factory->create (maindock, "hk_kdequerypart", "KParts::ReadWritePart");
     if (!p_part)
     {
      show_warningmessage(hk_translate("Fatal error! Query part could not be loaded!\nThis is a installation error. Check your installation!\
- Did you install knoda into the correct directory? Program will exit now...")); 
+ Did you install knoda into the correct directory? Program will exit now..."));
      exit(1);
-    } 
+    }
      p_partmanager->addPart(p_part);
      p_query = (hk_kdequerypartwidget*)p_part->widget();
      maindock->setWidget(p_query);
     setView(maindock);
     setMainDockWidget(maindock);
     connect(p_partmanager,SIGNAL(partRemoved(KParts::Part*)),this, SLOT(part_removed()));
-    p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(close_query()),actionCollection(),"closequery");
+    connect(p_partmanager,SIGNAL(activePartChanged(KParts::Part*)),this, SLOT(createGUI(KParts::Part*)));
+   p_closeaction=new KAction(i18n("&Close"),"fileclose",0,this,SLOT(close_query()),actionCollection(),"closequery");
     set_mode(designmode);
     createGUI(p_part);
 
@@ -145,7 +146,7 @@ bool hk_kdequery::save_query(const hk_string& n,bool ask)
 
     set_caption();
  if (!p_query) return false;
-    
+
  return p_query->save_query(n,ask);
 }
 
@@ -178,8 +179,8 @@ void hk_kdequery::closeEvent ( QCloseEvent* e)
         reset_has_changed();
 
     }
-    
-    
+
+
     KParts::DockMainWindow::closeEvent(e);
    emit signal_closed(this);
 
@@ -195,13 +196,13 @@ void hk_kdequery::set_caption(void)
     if (d!=NULL)
     {
         QString n=((d->type()==hk_datasource::ds_view)? i18n("View - "):i18n("Query - "));
-	
-        n+=QString::fromLocal8Bit(d->name().c_str());
+
+        n+=QString::fromUtf8(l2u(d->name()).c_str());
         n+=" (";
         hk_string driver=d->database()->name();
-        n+=QString::fromLocal8Bit(driver.c_str());
+        n+=QString::fromUtf8(l2u(driver).c_str());
         n+=")";
-	QString name=QString::fromLocal8Bit(d->database()->connection()->drivername().c_str())+" "+n;
+	QString name=QString::fromUtf8(l2u(d->database()->connection()->drivername()).c_str())+" "+n;
         setCaption(name);
     	KMdiChildView* v=dynamic_cast<KMdiChildView*>(parent());
         if (v) v->setCaption(n);
@@ -224,12 +225,12 @@ return p_query->in_designmode();
 void hk_kdequery::part_removed(void)
 {
    cerr <<"hk_kdequery::part_removed"<<endl;
-   
+
    p_part=NULL;
    p_query=NULL;
    close();
-   
-   
+
+
 }
 
 
@@ -266,7 +267,14 @@ void hk_kdequery::before_source_vanishes(void)
         hk_datasource* d=datasource();
         if (d!=NULL)d->disable();
         set_datasource(NULL);
-	
+
     }
     //hk_dsquery::before_source_vanishes();
 }
+
+
+void   hk_kdequery::createGUI (KParts::Part *part)
+{
+  if (p_part) KParts::DockMainWindow::createGUI(part);
+}
+
