@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.28 $
+//$Revision: 1.31 $
 
 #include "hk_kdequerypartwidget.h"
 #include "hk_kdequerypartwidget.moc"
@@ -134,6 +134,7 @@ hk_kdequerypartwidget::hk_kdequerypartwidget(hk_kdequerypart* part,QWidget* w,co
     p_selectallaction=NULL;
     p_configeditoraction=NULL;
     p_storeresultaction=NULL;
+    p_reloadaction=NULL;
 
     set_nodesignmode(runtime_only());
     designbutton_clicked();
@@ -410,7 +411,7 @@ void hk_kdequerypartwidget::internal_set_viewmode(void)
 	    }
 	    else
 	    {
-	     d->set_sql(u2l(p_private->p_designkate->getDoc()->text().utf8().data()),true);
+	     d->set_sql(u2l(p_private->p_designkate->getDoc()->text().utf8().data()),d->type()!=hk_data::ds_view);
 	    }
            d->set_progressdialog(&hk_kdequerypartwidget::set_progress);
            before_execute();
@@ -936,3 +937,23 @@ void hk_kdequerypartwidget::exec_cancelled(void)
     p_cancel=true;
 
 }
+
+
+
+void hk_kdequerypartwidget::reload_query()
+{
+
+    hk_datasource* d=p_private->p_grid->datasource();
+
+    if (d!=NULL)
+    {
+     unsigned long rp=d->row_position();
+
+     d->disable();
+     d->enable();
+     if (rp>0)
+       d->goto_row(rp);
+    }
+}
+
+
