@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.54 $
+//$Revision: 1.55 $
 
 #include "hk_kdereport.h"
 #include "hk_kdesimplereport.h"
@@ -259,11 +259,11 @@ void hk_kdereport::set_caption(void)
  
     QString reportname=i18n( "Report - "  );
     hk_database* db=database();
-        reportname+=QString::fromLocal8Bit (p_report->simplereport()->hk_presentation::name().c_str());
+        reportname+=QString::fromUtf8 (l2u(p_report->simplereport()->hk_presentation::name()).c_str());
         reportname+=" (";
         hk_string driver;
 	if (db) driver=db->name();
-        reportname+=QString::fromLocal8Bit(driver.c_str());
+        reportname+=QString::fromUtf8(l2u(driver).c_str());
         reportname+=")";
 
     setCaption( reportname  );
