@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.20 $
+//$Revision: 1.23 $
 
 #include "hk_kdereportpartwidget.h"
 #include "hk_kdetoolbar.h"
@@ -32,6 +32,7 @@
 #include <qclipboard.h>
 #include <qapplication.h>
 #include <qwidget.h>
+#include <qfile.h>
 
 #include <klibloader.h>
 #include <kmenubar.h>
@@ -43,6 +44,7 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <ktoolbar.h>
+#include <ktrader.h>
 #include <kmdichildview.h>
 
 
@@ -57,13 +59,13 @@ hk_kdepreviewwindow(QWidget * parent , const char * name = 0, WFlags f = WDestru
         p_toolbar=new KToolBar(this,"gvtoolbar",true);
 	p_toolbar->setBarPos(KToolBar::Top);
 	p_toolbar->setMovingEnabled(false);
+	QSizePolicy policy(QSizePolicy::Preferred,QSizePolicy::Preferred);
+	p_toolbar->setSizePolicy(policy);
+	QSizePolicy policy2(QSizePolicy::Expanding,QSizePolicy::Expanding);
 	l->addWidget(p_toolbar, AlignTop);
-        KLibFactory*    p_factory=KLibLoader::self()->factory("libkghostview");
-        if (!p_factory) p_factory=KLibLoader::self()->factory("libkghostviewpart");
 	p_previewpart=NULL;
-       p_previewpart=(KParts::ReadOnlyPart*) p_factory->create(this,"kgvpart","KParts::ReadOnlyPart");
-       if (p_previewpart) l->addWidget(p_previewpart->widget());
-       add_actions();
+	create_previewpart(l);
+        add_actions();
      }
 virtual ~hk_kdepreviewwindow()
         {
@@ -86,6 +88,40 @@ void add_actions(void)
    }
    //KAction* printact=new KAction(p_previewpart->widget(),SLOT(print()),NULL)   ;
   }
+  
+  
+  void create_previewpart(QVBoxLayout* l)
+  {
+	QSizePolicy policy2(QSizePolicy::Expanding,QSizePolicy::Expanding);
+        
+        KTrader::OfferList offers=KTrader::self()->query("application/postscript","'KParts/ReadOnlyPart' in ServiceTypes");
+        KTrader::OfferList::Iterator it(offers.begin());
+        
+        KLibFactory*    p_factory=NULL;
+        for (;it!=offers.end();++it)
+        {
+          KService::Ptr service=(*it);
+          p_factory=KLibLoader::self()->factory(QFile::encodeName(service->library()));
+          if (p_factory)
+           {
+            p_previewpart=static_cast<KParts::ReadOnlyPart*>
+            (p_factory->create(this,service->name().latin1(),"KParts::ReadOnlyPart"));
+            break;
+           }
+        }
+        
+        
+	
+       if (p_previewpart)
+	{
+	 l->addWidget(p_previewpart->widget());
+	p_previewpart->widget()->setSizePolicy(policy2);
+	}
+       else
+        show_warningmessage(hk_class::hk_translate("Could not find a preview part!"));
+
+  }
+
 KParts::ReadOnlyPart* p_previewpart;
 KToolBar* p_toolbar;
 
@@ -417,11 +453,7 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
 	    p_sectionaction->setEnabled(false);
 
         if (p_viewaction) p_viewaction->setChecked(true);
-        KLibFactory*    p_factory=KLibLoader::self()->factory("libkghostview");
-        if (!p_factory) p_factory=KLibLoader::self()->factory("libkghostviewpart");
-        if (p_factory)
-        {
-            if (p_previewwindow!=NULL)
+         if (p_previewwindow!=NULL)
 	    {
 		//createGUI(0L);
 		p_stack->removeWidget(p_previewwindow);
@@ -452,11 +484,6 @@ void    hk_kdereportpartwidget::set_mode(hk_presentation::enum_mode s)
         p_deleteaction->setEnabled(false);
 
 
-	}
-        else
-        {
-            show_warningmessage(hk_translate("KGhostview could not be found!\nPlease install the kdegraphics package"));
-        }
         p_bulkaction->setEnabled(false);
     }
     else
