@@ -35,7 +35,7 @@ class hk_kdereportpartwidgetscrollview;
  *
  *@short  KDE high level widget to display and design reports
  *@author Horst Knorr (hk_classes@knoda.org)
- *@version $Revision: 1.10 $
+ *@version $Revision: 1.11 $
  *
  *this is a high level widget to display and design reports. It hereby uses @ref hk_kdesimplereport.
  *To use it set the database with @ref set_database. If you want to show or edit an existing reports
@@ -62,7 +62,7 @@ friend class hk_kdereportpart;
 	void stop_execution(void);
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
 
 
 
