@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.57 $
+//$Revision: 1.62 $
 #include "hk_kdereportproperty.h"
 #include "hk_kdesimplereport.h"
 #include "hk_kdesubreportdialog.h"
@@ -96,18 +96,20 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
     p_report=parent;
     p_visible=NULL;
     p_fontdatabase = new QFontDatabase();
-    QStringList strlist=p_fontdatabase->families();
+    list<hk_string>* flist=hk_font::fontlist();
     QStringList newstrlist;
-    for (QStringList::iterator it=strlist.begin();it!=strlist.end();++it)
+    list<hk_string>::iterator it=flist->begin();
+    while(it!=flist->end())
     {
-        QString f=(*it);
-        int pos= f.find("[",0);
-        if (pos!=-1) f.truncate(pos-1);
+        QString f=QString::fromUtf8(l2u(*it).c_str());
+        /*int pos= f.find("[",0);
+        if (pos!=-1) f.strlist.begin()truncate(pos-1);
 	// eliminate fonts with a space in the name
 	pos=f.find(" ",0);
 	
-        if (!newstrlist.contains(f)&&pos==-1) 
+        if (!newstrlist.contains(f)&&pos==-1) */
 	   newstrlist.append(f);
+    ++it;
     }
 
     fontfield->insertStringList(newstrlist);
@@ -117,6 +119,9 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
     wordbreakfield->insertItem(yes);
     wordbreakfield->insertItem(no);
 
+    dynamicheightfield->insertItem(yes);
+    dynamicheightfield->insertItem(no);
+
     toplinefield->insertItem(yes);
     toplinefield->insertItem(no);
 
@@ -143,7 +148,7 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
     sortingfield->insertItem(i18n("Descending"));
 
     list<hk_string>* l=p_report->reporttypelist();
-    list<hk_string>::iterator it=l->begin();
+    it=l->begin();
     int i=0;
     while (it!=l->end())
     {
@@ -221,6 +226,11 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
     QToolTip::add(identifierfield,info);
     QToolTip::add(valuefield,info);
 
+    tab->changeTab(p_formatscrollview,i18n("&Format"));
+    tab->changeTab(p_datascrollview,i18n("&Data"));
+    tab->changeTab(p_actionscrollview,i18n("&Action"));
+    tab->changeTab(p_framescrollview,i18n("F&rame"));
+    
     QSize s=actiontab->geometry().size();
     if (frametab->width()>s.width())s.setWidth(frametab->width());
     if (formattab->width()>s.width())s.setWidth(formattab->width());
@@ -244,10 +254,8 @@ hk_kdereportproperty::hk_kdereportproperty( hk_kdesimplereport* parent,  const c
 
 
 
-    tab->changeTab(p_formatscrollview,i18n("&Format"));
-    tab->changeTab(p_datascrollview,i18n("&Data"));
-    tab->changeTab(p_actionscrollview,i18n("&Action"));
-    tab->changeTab(p_framescrollview,i18n("F&rame"));
+
+
 
 
 
@@ -406,9 +414,9 @@ void hk_kdereportproperty::datasourcebutton_clicked()
     hkdebug("hk_kdereportproperty::datasourcebutton_clicked");
 #endif
     hk_kdeformdatasourcedialog* d = new hk_kdeformdatasourcedialog(p_report,this,0,true);
+    d->set_displaytype(hk_kdeformdatasourcedialog::d_report);
     hk_datasource* ds=p_report->get_datasource(u2l(datasourcefield->currentText().utf8().data()));
     d->set_datasource(ds);
-    d->set_displaytype(hk_kdeformdatasourcedialog::d_report);
     if (ds)
     {
         d->alterbutton->setEnabled(true);
@@ -468,6 +476,7 @@ void hk_kdereportproperty::set_object(hk_visible* v)
     valuefield->setEnabled(false);
     reporttypefield->setEnabled(false);
     wordbreakfield->setEnabled(true);
+    dynamicheightfield->setEnabled(false);
     widthfield->setEnabled(false);
     heightfield->setEnabled(false);
     toplinefield->setEnabled(true);
@@ -549,6 +558,7 @@ void hk_kdereportproperty::set_object(hk_visible* v)
 
             widthfield->setEnabled(true);
             heightfield->setEnabled(true);
+            dynamicheightfield->setEnabled(true);
             wordbreaklabel->setText(i18n("Wordbreak:"));
             runningcountlabel->setText(i18n("Running count:"));
             runningcountfield->setEnabled(true);
@@ -565,6 +575,7 @@ void hk_kdereportproperty::set_object(hk_visible* v)
             if (firstpagenumberfield!=NULL)firstpagenumberfield->setEnabled(false);
             wordbreakfield->setEnabled(true);
             wordbreaklabel->setText(i18n("New page:"));
+            dynamicheightfield->setEnabled(false);
             toplinefield->setEnabled(false);
             leftlinefield->setEnabled(false);
             rightlinefield->setEnabled(false);
@@ -835,9 +846,13 @@ void hk_kdereportproperty::set_reportdatavisible(void)
     alignmentfield->blockSignals(false);
 
     wordbreakfield->blockSignals(true);
-    wordbreakfield->setCurrentItem(d->wordbreak()?0:1);
+    wordbreakfield->setCurrentItem(d->linebreak()?0:1);
     wordbreakfield->blockSignals(false);
 
+    dynamicheightfield->blockSignals(true);
+    dynamicheightfield->setCurrentItem(d->dynamic_height()?0:1);
+    dynamicheightfield->blockSignals(false);
+
     leftlinefield->blockSignals(true);
     leftlinefield->setCurrentItem(d->leftline()?0:1);
     leftlinefield->blockSignals(false);
@@ -1211,7 +1226,8 @@ void hk_kdereportproperty::set_objectreportdatavisible(void)
     }
     rd->set_alignment(at);
 
-    rd->set_wordbreak(wordbreakfield->currentItem()==0);
+    rd->set_linebreak(wordbreakfield->currentItem()==0);
+    rd->set_dynamic_height(dynamicheightfield->currentItem()==0);
     rd->set_leftline(leftlinefield->currentItem()==0);
     rd->set_rightline(rightlinefield->currentItem()==0);
     rd->set_topline(toplinefield->currentItem()==0);
