@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.140 $
+//$Revision: 1.141 $
 #include "hk_kdesimpleform.h"
 #include "hk_kdeform.h"
 #include "hk_kdeformpartwidget.h"
@@ -937,7 +937,7 @@ void hk_kdesimpleform::widget_specific_modechanges(enum_mode s)
 
 void hk_kdesimpleform::widget_specific_after_loadform(void)
 {
-    clearfocus();
+//     clearfocus();
 //     qApp->processEvents();
 }
 
@@ -1044,14 +1044,27 @@ void hk_kdesimpleform::clearfocus(void)
 #ifdef HK_DEBUG
     hkdebug("hk_kdesimpleform::clearfocus");
 #endif
+//     cerr <<"clear():vor p_focus->set_widget(NULL)"<<endl;
     if (p_focus!=NULL) p_focus->set_widget(NULL);
     //p_controlbutton=false;
+//     cerr <<"clear():nach p_focus->set_widget(NULL)"<<endl;
     clearmultiplefocus();
+//     cerr <<"clear():nach clearmultiplefocus"<<endl;
     enable_actions();
+//     cerr <<"clear():nach enablea"<<endl;
+    if (p_property && mode()==designmode) p_property->set_object(NULL);
 	emit signal_focuswidget_changed();
 }
 
 
+
+void hk_kdesimpleform::loaddata(xmlNodePtr definition)
+{
+clearfocus();
+  hk_form::loaddata(definition);
+}
+
+
 void hk_kdesimpleform::set_focus(QWidget*f, bool p_controlbutton)
 {
 #ifdef HK_DEBUG
