@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.136 $
+//$Revision: 1.140 $
 
 #include "hk_kdesimplegrid.h"
 #include "hk_kdesimplegrid.moc"
@@ -197,8 +197,10 @@ void internalcheckbox::paintEvent(QPaintEvent*)
     switch (draw)
     {
     case 1: { // TRUE
+//         const QBrush brush =QBrush(selected&&!(currentcell && hasFocus())?colorGroup().highlightedText():colorGroup().text());
+//         qDrawPlainRect(painter,left+3,top+3,square/2,square/2,colorGroup().dark(),1,&brush);
 
-        const QBrush brush =QBrush(colorGroup().highlightedText());
+        const QBrush brush =QBrush(colorGroup().text());
         qDrawPlainRect(&painter,left+3,top+3,square/2,square/2,colorGroup().dark(),1,&brush);
             break;
 	    }
@@ -231,10 +233,7 @@ void internalcheckbox::keyPressEvent(QKeyEvent* e)
 #endif
     if ((e->key()==Key_Space)&&(column()!=NULL))
     {
-        if (column()->has_changed())
-            column()->set_asbool(!column()->changed_data_asbool());
-        else
-            column()->set_asbool(!column()->asbool());
+        toggle_value();
     }
 
     blinkon();
@@ -247,6 +246,11 @@ void internalcheckbox::mousePressEvent(QMouseEvent* )
 #ifdef HK_DEBUG
     hkdebug ("internalcheckbox::mousePressEvent");
 #endif
+toggle_value();
+}
+
+void internalcheckbox::toggle_value()
+{
     if (column()!=NULL)
     {
         if (column()->has_changed())
@@ -274,11 +278,10 @@ void internalcheckbox::mousePressEvent(QMouseEvent* )
 	   }
 //            column()->set_asbool(!column()->asbool());
 	}
-    }else cerr <<"internalcheckbox::mousePressEvent() ist NULL"<<endl;
+    }else cerr <<"internalcheckbox::toggle_value() ist NULL"<<endl;
     blinkcursorslot();
+
 }
-
-
 //****************************************************************
 //***   hk_kdesimplegrid begin                                 ***
 //****************************************************************
@@ -391,7 +394,7 @@ void hk_kdesimplegrid::columns_created(void)
 if (!datasource()) return;
 clear_vertical_header();
 
-        setSorting(!datasource()->is_rawsql());
+        setSorting(!datasource()->is_rawsql()||datasource()->type()==hk_data::ds_view);
         if (datasource()->is_enabled())
         {
             if(datasource()->columns()!=NULL)
@@ -655,6 +658,7 @@ QWidget* hk_kdesimplegrid::createEditor(int row, int col,bool ) const
             i->set_datasource(p_grid->datasource());
             i->set_columnname(p_grid->gridcolumn(col)->columnname());
 	    i->set_gridcolumn(p_grid->gridcolumn(col));
+	    i->toggle_value();
 
             break;
         }
@@ -1172,6 +1176,10 @@ void hk_kdesimplegrid::show_contextmenu(int , int , const QPoint& pos)
     {
     id[ 10 ] = popup->insertItem( i18n( "Paste" ),CTRL+Key_V );
     }
+    popup->insertSeparator();
+    id[ 11 ] = popup->insertItem( i18n( "Reload" ) );
+    
+    
     int r = popup->exec( pos );
 
     if (r==id[3]&&datasource()!=NULL)datasource()->delete_actualrow();
@@ -1200,6 +1208,15 @@ void hk_kdesimplegrid::show_contextmenu(int , int , const QPoint& pos)
     {
      paste();
     }
+    else if (id[11]==r && datasource())
+    {
+     unsigned long rp=datasource()->row_position();
+      datasource()->disable();
+      datasource()->enable();
+     if (rp>0)
+       datasource()->goto_row(rp);
+    }
+    
         delete popup;
     return;
 }
@@ -1329,7 +1346,8 @@ void hk_kdesimplegrid::sortColumn( int col, bool ascending, bool /*wholeRows*/)
     if (p_grid->gridcolumn(col))
     {
     hk_string colname = defaultidentifierdelimiter+p_grid->gridcolumn(col)->columnname()+defaultidentifierdelimiter;
-    if (!ascending) colname+=" DESC ";
+    if (!ascending) colname+=" DESC "; 
+//     cerr <<"set_use_temporarysorting #"<<colname<<"#"<<endl;
     datasource()->set_temporarysorting(colname);
     }
     datasource()->disable();
