@@ -12,6 +12,9 @@
 #ifndef HK_KDESPINBOX
 #define HK_KDESPINBOX
 #include <qspinbox.h>
+#include <qvalidator.h>
+#include<hk_font.h>
+
 class hk_kdespinboxvalidator;
 class hk_kdespinbox : public QSpinBox
 {
@@ -34,4 +37,6 @@ class hk_kdespinbox : public QSpinBox
         enum_displaytype p_displaytype;
         hk_kdespinboxvalidator* p_validator;
 };
+
+
 #endif
