@@ -23,7 +23,7 @@ hk_kdesubform(hk_kdesimpleform*);
 virtual ~hk_kdesubform();
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
 
 protected:
 bool widget_specific_coordinates(uint px,uint py,uint pwidth,uint pheight);
