@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.11 $
+//$Revision: 1.12 $
 #include "hk_kdesubreportdialog.h"
 #include <hk_string.h>
 #include <hk_reportsection.h>
@@ -61,7 +61,7 @@ hk_kdesubreportdialog::hk_kdesubreportdialog( hk_reportsection* s,QWidget* paren
     if  (p_report!=NULL)
     {
         buffer+=" - ";
-        buffer+=QString::fromLocal8Bit(p_report->name().c_str());
+        buffer+=QString::fromUtf8(l2u(p_report->name()).c_str());
     }
     setCaption(buffer);
 
@@ -122,7 +122,7 @@ void hk_kdesubreportdialog::subreport_selected()
     if (subreportfield->currentText().isEmpty())return;
     hk_report* r= new hk_report();
     r->set_database(p_report->database());
-    r->load_report(subreportfield->currentText().local8Bit().data());
+    r->load_report(u2l(subreportfield->currentText().utf8().data()));
     hk_datasource* ds= r->datasource();
     if (ds==NULL) return;
     list<hk_column*>* v=ds->columns();
@@ -135,7 +135,7 @@ void hk_kdesubreportdialog::subreport_selected()
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        thisfield->insertItem(QString::fromLocal8Bit((*it)->name().c_str()));
+        thisfield->insertItem(QString::fromUtf8(l2u((*it)->name()).c_str()));
         it++;
     }
     delete r;
@@ -169,14 +169,14 @@ void hk_kdesubreportdialog::set_subreport()
 {
     if (p_section!=NULL)
     {
-        p_section->set_subreport(subreportfield->currentText().local8Bit().data(),printbeforefield->isChecked());
+        p_section->set_subreport(u2l(subreportfield->currentText().utf8().data()),printbeforefield->isChecked());
         p_section->clear_depending_fields();
         QListViewItem* i=dependingfieldlist->firstChild();
         while (i!=NULL)
         {
             QString st1 = i->text(1);
             QString st2 = i->text(0);
-            p_section->add_depending_fields(st1.local8Bit().data(),st2.local8Bit().data());
+            p_section->add_depending_fields(u2l(st1.utf8().data()),u2l(st2.utf8().data()));
             i=i->itemBelow();
         }
 
@@ -215,7 +215,7 @@ void hk_kdesubreportdialog::set_subreportlist()
 
     while(it!=l->end())
     {
-        if ((*it)!=p_report->name())subreportfield->insertItem(QString::fromLocal8Bit((*it).c_str()));
+        if ((*it)!=p_report->name())subreportfield->insertItem(QString::fromUtf8(l2u((*it)).c_str()));
         it++;
     }
 }
@@ -233,7 +233,7 @@ void hk_kdesubreportdialog::set_masterfield(void)
     list<hk_column*>::iterator it=v->begin();
     while (it!=v->end())
     {
-        masterfield->insertItem(QString::fromLocal8Bit((*it)->name().c_str()));
+        masterfield->insertItem(QString::fromUtf8(l2u((*it)->name()).c_str()));
         it++;
     }
 
@@ -252,7 +252,7 @@ void hk_kdesubreportdialog::set_reportsection(hk_reportsection* s)
 
     if (s==NULL) return;
     int c=0;
-    QString t=QString::fromLocal8Bit(p_section->subreportname().c_str());
+    QString t=QString::fromUtf8(l2u(p_section->subreportname()).c_str());
     while (c<subreportfield->count())
     {
         if (subreportfield->text(c)==t)
@@ -272,7 +272,7 @@ void hk_kdesubreportdialog::set_reportsection(hk_reportsection* s)
     QListViewItem* item= NULL;
     while ((this_it!=thislist->end())&&(sub_it!=sublist->end()))
     {
-        item=new QListViewItem(dependingfieldlist,QString::fromLocal8Bit((*sub_it).c_str()),QString::fromLocal8Bit((*this_it).c_str()));
+        item=new QListViewItem(dependingfieldlist,QString::fromUtf8(l2u((*sub_it)).c_str()),QString::fromUtf8(l2u((*this_it)).c_str()));
         sub_it++;
         this_it++;
     }
