@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.44 $
+//$Revision: 1.46 $
 
 #include "hk_kdetabledesign.h"
 #include "hk_kdetabledesign.moc"
@@ -294,6 +294,7 @@ void hk_kdetabledesign::create_columntypelist(void)
 
     }
     if (datasource()!=NULL)
+    {
         if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_MEMOCOLUMN))
     {
 
@@ -304,18 +305,23 @@ void hk_kdetabledesign::create_columntypelist(void)
         columntype_dictionary.insert(columntype_dictionary.end(),dict);
     }
 
+        if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_INTEGERCOLUMN))
+    {
     ftypename= i18n( "Integer" );
     typefield->insertItem(ftypename  );
     dict.name=ftypename;
     dict.type=hk_column::integercolumn;
     columntype_dictionary.insert(columntype_dictionary.end(),dict);
-
+}
+        if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_SMALLINTEGERCOLUMN))
+    {
     ftypename= i18n( "Small Integer" );
     typefield->insertItem(ftypename  );
     dict.name=ftypename;
     dict.type=hk_column::smallintegercolumn;
     columntype_dictionary.insert(columntype_dictionary.end(),dict);
-
+    }
+    
     if (datasource()!=NULL)
         if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_AUTOINCCOLUMN))
     {
@@ -326,18 +332,25 @@ void hk_kdetabledesign::create_columntypelist(void)
         columntype_dictionary.insert(columntype_dictionary.end(),dict);
     }
 
+        if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_FLOATINGCOLUMN))
+    {
     ftypename= i18n( "Float" );
     typefield->insertItem(ftypename  );
     dict.name=ftypename;
     dict.type=hk_column::floatingcolumn;
     columntype_dictionary.insert(columntype_dictionary.end(),dict);
-
+    }
+    
+    
+        if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_SMALLFLOATINGCOLUMN))
+    {
     ftypename= i18n( "Small Float" );
     typefield->insertItem(ftypename  );
     dict.name=ftypename;
     dict.type=hk_column::smallfloatingcolumn;
     columntype_dictionary.insert(columntype_dictionary.end(),dict);
-
+    }
+    }
     if (datasource()!=NULL)
         if (datasource()->database()->connection()->server_supports(hk_connection::SUPPORTS_BOOLCOLUMN))
     {
