@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.10 $
+//$Revision: 1.12 $
 
 #include "hk_kdetablepartwidget.h"
 #include <hk_datasource.h>
@@ -64,6 +64,7 @@ hk_kdetablepartwidget::hk_kdetablepartwidget(QWidget* w,const char* n,WFlags f):
     p_copyaction=NULL;
     p_pasteaction=NULL;
     p_columndialogaction=NULL;
+    p_reloadaction=NULL;
     p_saveaction=NULL;
     p_autoclose=true;
     KLibFactory* p_factory= KLibLoader::self()->factory( "libhk_kdegridpart" );
@@ -152,6 +153,8 @@ void hk_kdetablepartwidget::internal_designbutton_clicked(void)
     p_designaction->setChecked(true);
     if (p_printaction)
      p_printaction->setEnabled(false);
+    if (p_reloadaction)
+     p_reloadaction->setEnabled(false);
 //   p_filterdefinitionaction->setEnabled(false);
     set_caption();
     if (p_columndialogaction)
@@ -191,6 +194,8 @@ void hk_kdetablepartwidget::internal_tablebutton_clicked(void)
     p_toolbar->set_viewmode();
     if (p_viewaction)p_viewaction->setChecked(true);
     if (p_filterdefinitionaction)p_filterdefinitionaction->setEnabled(true);
+    if (p_reloadaction)
+     p_reloadaction->setEnabled(true);
     set_caption();
     if (p_columndialogaction)
     p_columndialogaction->setEnabled(true);
@@ -388,3 +393,16 @@ void hk_kdetablepartwidget::exec_cancelled(void)
 
 }
 
+void hk_kdetablepartwidget::reload_table()
+{
+    hk_datasource* d=p_grid->datasource();
+    if (d!=NULL)
+    {
+     unsigned long rp=d->row_position();
+     d->disable();
+     d->enable();
+     if (rp>0)
+       d->goto_row(rp);
+    }
+
+}
