@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//Version $Revision: 1.26 $
+//Version $Revision: 1.33 $
 
 #include "hk_kdetoolbar.h"
 #include <qlayout.h>
@@ -33,6 +33,7 @@ hk_kdetoolbar::hk_kdetoolbar(QWidget* w,const char* s) :QObject(w,s) ,hk_dsvisib
     p_filterdefinitionaction=NULL;
     p_filterexecaction=NULL;
     p_parent=w;
+    p_use_filter=false;
     p_filter_should_be_activated=p_is_activated=false;
     p_viewmode=false;
     p_nodesignmode=false;
@@ -91,8 +92,9 @@ void hk_kdetoolbar::set_viewmode(void)
     if (!datasource())return;
     if( p_filter_should_be_activated) activate_filter();
     if (p_filterexecaction)
-    {
-        p_filterexecaction->setEnabled(!p_filter.isEmpty());
+    { 
+    //cerr <<"TOOLBAR set_viewmode"<<endl;
+        p_filterexecaction->setEnabled(true);
     }
 // if (p_filterdefinitionaction)p_filterdefinitionaction->setEnabled((p_filterexecaction?!p_filterexecaction->isChecked():true));
 
@@ -119,7 +121,10 @@ void hk_kdetoolbar::filterdefinebutton_clicked()
     {
         set_filter(f->textfield->text());
     };
-
+    p_filterdefinitionaction->setChecked(!p_filterdefinitionaction->isChecked());
+    p_is_activated=false;
+    if (!p_filterdefinitionaction->isChecked()&&p_filterexecaction->isChecked())
+       filterexecbutton_clicked();
     delete f;
 }
 
@@ -127,13 +132,14 @@ void hk_kdetoolbar::filterdefinebutton_clicked()
 void hk_kdetoolbar::set_filter(const QString& s)
 {
 #ifdef HK_DEBUG
-    hkdebug("hk_kdetoolbar::set_filter");
+    hkdebug("hk_kdetoolbar::set_filter(QString)");
 #endif
     if (!datasource())return;
-    p_filter=s;
-    if (p_filterexecaction)p_filterexecaction->setEnabled(!p_filter.isEmpty());
+    p_filter=s; //cerr <<"SETFILTER:"<<s<<endl;
+    p_use_filter=!p_filter.isEmpty();
+    if (p_filterexecaction)p_filterexecaction->setEnabled(true);
 
-    datasource()->set_temporaryfilter(p_filter.local8Bit().data());
+    datasource()->set_temporaryfilter(u2l(p_filter.utf8().data()));
     if (p_filterexecaction->isChecked())
     {
         p_is_activated=false;
@@ -147,6 +153,29 @@ void hk_kdetoolbar::set_filter(const QString& s)
 }
 
 
+void hk_kdetoolbar::set_filter(bool s)
+{
+#ifdef HK_DEBUG
+    hkdebug("hk_kdetoolbar::set_filter(bool)");
+#endif
+    if (!datasource())return;
+    p_filter=""; //cerr <<"SETFILTER"<<endl;
+    p_use_filter=s;
+    if (p_filterexecaction)p_filterexecaction->setEnabled(true);
+
+    if (p_filterexecaction->isChecked())
+    {
+        p_is_activated=false;
+//         filterexecbutton_clicked();
+    }
+    if (!p_filterexecaction->isEnabled())
+    {
+        p_filterexecaction->setChecked(false);
+        p_is_activated=false;
+    }
+}
+
+
 void hk_kdetoolbar::filterexecbutton_clicked()
 {
 #ifdef HK_DEBUG
@@ -154,9 +183,10 @@ void hk_kdetoolbar::filterexecbutton_clicked()
 #endif
     if (datasource()==NULL||!p_filterexecaction)return;
 
-    if (p_filterexecaction->isChecked())
+    if (p_filterexecaction->isChecked() )
     {
-        activate_filter();
+        if (!p_filterdefinitionaction->isChecked())
+         activate_filter();
         p_filter_should_be_activated=true;
 
     }
@@ -181,7 +211,7 @@ void hk_kdetoolbar::deactivate_filter(void)
     datasource()->disable();
     datasource()->set_use_temporaryfilter(false);
 //   datasource()->set_filter(p_originalfilter,false);
-    if (p_viewmode)   datasource()->enable();
+    if (p_viewmode &&! p_filterdefinitionaction->isChecked())   datasource()->enable();
     p_is_activated=false;
 
 }
@@ -197,7 +227,8 @@ void hk_kdetoolbar::activate_filter(void)
     if (datasource()==NULL) return;
     if (p_is_activated) return;
     datasource()->disable();
-    datasource()->set_temporaryfilter(p_filter.local8Bit().data());
+    if (!p_filter.isEmpty())
+       datasource()->set_temporaryfilter(u2l(p_filter.utf8().data()));
     datasource()->set_use_temporaryfilter(true);
     if (p_viewmode) datasource()->enable();
     p_filter_should_be_activated=p_is_activated=true;
@@ -213,13 +244,16 @@ bool hk_kdetoolbar::is_filter_activated(void)
 }
 
 
-void hk_kdetoolbar::set_filteractions(KAction* filterdefinition,KToggleAction* filterexec)
+void hk_kdetoolbar::set_filteractions(KToggleAction* filterdefinition,KToggleAction* filterexec)
 {
     p_filterdefinitionaction=filterdefinition;
     p_filterexecaction=filterexec;
     if (p_filterdefinitionaction)
         p_filterdefinitionaction->setToolTip(i18n( "Filter definition" ) );
     if (p_filterexecaction)
+    {
         p_filterexecaction->setToolTip(i18n( "Filter execution" ));
+        p_filterexecaction->setEnabled(true);
+    }
 
 }
