@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//Version $Revision: 1.14 $
+//Version $Revision: 1.16 $
 
 #ifndef HK_KDETOOLBAR_H
 #define HK_KDETOOLBAR_H
@@ -33,11 +33,12 @@ class hk_kdetoolbar : public QObject ,public hk_dsvisible
         void set_viewmode(void);
         void set_nodesignmode(bool);
         bool is_filter_activated(void);
-        void set_filteractions(KAction* filterdefinition,KToggleAction* filterexec);
+        void set_filteractions(KToggleAction* filterdefinition,KToggleAction* filterexec);
     public slots:
         void deactivate_filter(void);
 
         void set_filter(const QString& s);
+        void set_filter(bool);
 
     protected:
 
@@ -58,11 +59,12 @@ class hk_kdetoolbar : public QObject ,public hk_dsvisible
         bool p_showsearchbutton;
         bool p_is_activated;
         bool p_filter_should_be_activated;
+        bool p_use_filter;
         QString p_filter;
         hk_string p_originalfilter;
         bool p_viewmode;
         QWidget* p_parent;
-        KAction*      p_filterdefinitionaction;
+        KToggleAction*      p_filterdefinitionaction;
         KToggleAction*    p_filterexecaction;
 };
 #endif
