@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.52 $
+//$Revision: 1.56 $
 #include "knodamaindockwindowbase.h"
 #include "knodamaindockwindow.h"
 #include "hk_kdedblistview.h"
@@ -19,9 +19,11 @@
 #include <hk_dsvisible.h>
 #include <hk_database.h>
 #include <hk_report.h>
+#include <hk_form.h>
 #include <hk_referentialintegrity.h>
 #include <hk_drivermanager.h>
 
+#include <qapplication.h>
 #include <qpixmap.h>
 #include <qclipboard.h>
 #include <qtoolbutton.h>
@@ -31,6 +33,7 @@
 #include <kcombobox.h>
 #include <kdockwidget.h>
 #include <kfiledialog.h>
+#include <kdirselectdialog.h>
 #include <kmdichildview.h>
 #include <kconfig.h>
 #include <klocale.h>
@@ -180,12 +183,14 @@ knodamaindockwindowbase::knodamaindockwindowbase(struct_commandlinefields* cl,
     p_newviewaction= new KAction(i18n("View"),"filefind",0,this,SLOT(slot_new_view()),actionCollection(),"newview");
     p_newformaction= new KAction(i18n("Form"),"openterm",0,this,SLOT(slot_new_form()),actionCollection(),"newform");
     p_newreportaction= new KAction(i18n("Report"),"fileprint",0,this,SLOT(slot_new_report()),actionCollection(),"newreport");
+    p_newmoduleaction= new KAction(i18n("Module"),"edit",0,this,SLOT(slot_new_module()),actionCollection(),"newmodule");
     p_newobjectaction->insert(p_newdatabaseaction);
     p_newobjectaction->insert(p_newtableaction);
     p_newobjectaction->insert(p_newviewaction);
     p_newobjectaction->insert(p_newqueryaction);
     p_newobjectaction->insert(p_newformaction);
     p_newobjectaction->insert(p_newreportaction);
+    p_newobjectaction->insert(p_newmoduleaction);
 
 
     p_displaymodeaction= new KActionMenu(i18n("Displaymode"),0,actionCollection(),"displaymode");
@@ -286,8 +291,14 @@ knodamaindockwindowbase::knodamaindockwindowbase(struct_commandlinefields* cl,
    connect(p_listview,SIGNAL(signal_designmode_report(const QString&)),this,SLOT(slot_designmode_report(const QString&)));
    connect(p_listview,SIGNAL(signal_delete_report(const QString&)),this,SLOT(slot_delete_report(const QString&)));
    connect(p_listview,SIGNAL(signal_new_report(void)),this,SLOT(slot_new_report(void)));
+
+   connect(p_listview,SIGNAL(signal_designmode_module(const QString&)),this,SLOT(slot_designmode_module(const QString&)));
+   connect(p_listview,SIGNAL(signal_delete_module(const QString&)),this,SLOT(slot_delete_module(const QString&)));
+   connect(p_listview,SIGNAL(signal_new_module(void)),this,SLOT(slot_new_module(void)));
+   
    connect(p_listview, SIGNAL(contextMenuRequested(QListViewItem*,const QPoint&, int)),
    this,SLOT(slot_listbox_popup(QListViewItem*,const QPoint&)));
+   
    }
 //   createShellGUI(true);
    createGUI(0L);
@@ -369,6 +380,7 @@ c->setGroup("knodamain");
 c->writeEntry("MDIMode",value);
 writeDockConfig(c,"knodamaindock");
 }
+
 while (m_pCurrentWindow)
 {     //cerr<<"   closewindow: "<<m_pCurrentWindow->className()<<endl;
        hk_report* r=dynamic_cast<hk_report*>(m_pCurrentWindow->focusedChildWidget());
@@ -379,15 +391,32 @@ while (m_pCurrentWindow)
 	   return;
 
 	 }
+	else
+	{ 
+	QWidget* w=m_pCurrentWindow->focusedChildWidget();
+	while (w)
+	{
+	
+	hk_form* f=dynamic_cast<hk_form*>(w);
+	if (f&&f->while_load_form())
+	{
+	   event->ignore();
+	 show_warningmessage("close while_loadform");
+	 return;
+	}
+	w=w->parentWidget();
+	}
+	}
       closeWindow(m_pCurrentWindow);
 }
+KMdiMainFrm::closeEvent(event);
+qApp->processEvents();
 if (p_database)
-   {
-      p_database->disable();
+   { 
+       p_database->disable();
       delete p_database;
    }
 p_database=NULL;
-KMdiMainFrm::closeEvent(event);
 }
 
 
@@ -739,17 +768,35 @@ void knodamaindockwindowbase::slot_open_localdatabase()
   l.append(xmime);cerr <<"add xmime:"<<xmime<<endl;
   l.append("all/allfiles");
   QString p=":"+QString::fromUtf8(l2u(p_connection->drivername()).c_str());
-KFileDialog* d=new KFileDialog(p,QString::null,this,0,true);
-d->setMimeFilter(l,xmime);
-d->exec();
-QString filename=d->selectedFile();
+  QString filename;
+  filename=QString::null;
+
+  if (p_connection->server_needs(hk_connection::NEEDS_DIRECTORY_AS_DATABASE))
+  {
+    KDirSelectDialog* d=new KDirSelectDialog(p,false,this,0,true);
+    d->exec();
+    filename=d->url().directory(false,false);
+    if (!filename.isNull())
+      if (!d->url().fileName().isEmpty())
+      filename+=d->url().fileName();
+    delete d;
+  
+  }
+  else
+  {
+    KFileDialog* d=new KFileDialog(p,QString::null,this,0,true);
+    d->setMimeFilter(l,xmime);
+    d->exec();
+    filename=d->selectedFile();
+    delete d;
+  }
   if (!filename.isNull())
   {
+  cerr <<"FILENAME="<<filename<<endl;
       if (p_databasecombobox)
         p_databasecombobox->insertItem(filename);
      internal_set_database(u2l(filename.utf8().data()));
   }
-delete d;
 }
 
 
