@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.3 $
+//$Revision: 1.4 $
 
 //***********************************************
 //***  hk_kdedbdesigner PART definition             ***
@@ -100,7 +100,7 @@ hk_kdedbdesigner* hk_kdedbdesignerpart::dbdesigner(void)
 
 void hk_kdedbdesignerpart::add_action(void)
 {
-p_private->p_dbdesigner->add_datasource();
+if (p_private->p_dbdesigner)p_private->p_dbdesigner->add_datasource();
 }
 
 
