@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.10 $
+//$Revision: 1.11 $
 
 //***********************************************
 //***  hk_kdegrid PART definition             ***
@@ -95,19 +95,19 @@ bool hk_kdegridpart::openFile()
 
     
     if (!p_drivermanager) p_drivermanager=new hk_drivermanager;
-    hk_connection* con=p_drivermanager->new_connection(url.protocol().local8Bit().data());
+    hk_connection* con=p_drivermanager->new_connection(u2l(url.protocol().utf8().data()));
     if (!con) return false;
-    if (url.hasHost()) con->set_host(url.host().local8Bit().data());
+    if (url.hasHost()) con->set_host(u2l(url.host().utf8().data()));
     if (url.port()!=0) con->set_tcp_port(url.port());
-    if (url.hasUser()) con->set_user(url.user().local8Bit().data());
-    if (url.hasPass()) con->set_password(url.pass().local8Bit().data());
+    if (url.hasUser()) con->set_user(u2l(url.user().utf8().data()));
+    if (url.hasPass()) con->set_password(u2l(url.pass().utf8().data()));
     if (!con->connect())
     {
       delete con;
       return false;
     }  
-    hk_database* db= con->new_database(databasename.local8Bit().data());
-    hk_datasource* ds=db->load_datasource(dsname.local8Bit().data(),dt);
+    hk_database* db= con->new_database(u2l(databasename.utf8().data()));
+    hk_datasource* ds=db->load_datasource(u2l(dsname.utf8().data()),dt);
     p_grid->set_datasource(ds);
     if (ds) ds->enable();
     return true;
