@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2004 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
 // This file is part of the hk_kdeclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -14,5 +14,5 @@
 #include "hk_kdeqbepart.h"
 //defining the factory
 typedef KParts::GenericFactory<hk_kdeqbepart> hk_kdeqbepartfactory;
-K_EXPORT_COMPONENT_FACTORY( libhk_kdeqbepart, hk_kdeqbepartfactory );
+K_EXPORT_COMPONENT_FACTORY( libhk_kdeqbepart, hk_kdeqbepartfactory )
 #endif
